const { ipcRenderer } = require('electron');
const os = require('os');
const fs = require('fs');
const path = require('path');
const ini = require('ini');


document.addEventListener('DOMContentLoaded', () => {
    const activationButton = document.getElementById('activate-button');
    if (activationButton) {
        activationButton.addEventListener('click', activate);
    }

        // 加载激活码
    loadActivationCode();
});

function loadActivationCode() {
    const userDataPath = ipcRenderer.sendSync('get-user-data-path'); // 同步请求用户数据路径
    const configFileName = 'qq-config.ini';
    const configPath = path.join(userDataPath, configFileName);

    try {
        const config = ini.parse(fs.readFileSync(configPath, 'utf-8'));
        const activationCode = config.activation_code;
        if (activationCode) {
            document.getElementById('activation-code').value = activationCode;
        }
    } catch (error) {
        console.log('配置文件未找到或读取错误:', error);
    }
}

function getMacAddress() {
    const interfaces = os.networkInterfaces();
    for (const interfaceName in interfaces) {
        const interface = interfaces[interfaceName];
        for (const info of interface) {
            if (!info.internal && info.mac) {
                return info.mac;
            }
        }
    }
    return 'Unknown';
}

function activate() {
    const activationCode = document.getElementById('activation-code').value;
    const deviceSerial = getMacAddress();

    const data = new URLSearchParams();
    data.append('activation_code', activationCode);
    data.append('device_serial', deviceSerial);

    fetch('接口地址', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded'
        },
        body: data
    })
    .then(response => response.json())
    .then(result => {
        if (result.success) {
            ipcRenderer.send('show-alert', '激活成功！');
            document.getElementById('activation-status').innerText = '激活成功！';
            saveConfig(activationCode, deviceSerial); // 保存配置
            ipcRenderer.send('activate-success');  // 通知主进程打开新窗口
           

        } else {
            document.getElementById('activation-status').innerText = '激活失败：' + (result.error || '未知错误');
            if (result.error === '设备不匹配，请请求换绑') {
                console.log("ces");
                showModal();
            }
        }
    })
    .catch(error => {
        console.error('Error:', error);
        ipcRenderer.send('show-alert', '网络错误或服务器无响应');
        document.getElementById('activation-status').innerText = '网络错误或服务器无响应';
    });

}


function saveConfig(activationCode, deviceSerial) {
    const userDataPath = ipcRenderer.sendSync('get-user-data-path'); // 同步请求用户数据路径
    const configFileName = 'qq-config.ini';
    const configPath = path.join(userDataPath, configFileName);

    let config;
    try {
        config = ini.parse(fs.readFileSync(configPath, 'utf-8'));
    } catch (error) {
        if (error.code === 'ENOENT') {
            config = {};
        } else {
            throw error;
        }
    }
    config.activation_code = activationCode;
    config.device_serial = deviceSerial;
    fs.writeFileSync(configPath, ini.stringify(config), 'utf-8');
}


function showModal() {
    document.getElementById('custom-modal-container').classList.add('active');
    document.getElementById('custom-modal-container').style.display = 'block';  // 确保模态框也显示

    document.getElementById('custom-modal').style.display = 'block';  // 确保模态框也显示
}

function hideModal() {
    document.getElementById('custom-modal-container').classList.remove('active');
    document.getElementById('custom-modal-container').style.display = 'none';  // 确保模态框也显示

    document.getElementById('custom-modal').style.display = 'none';  // 隐藏模态框
}



function confirmChange() {
    hideModal(); // 隐藏模态框
    const activationCode = document.getElementById('activation-code').value;
    const deviceSerial = getMacAddress();
    changeDevice(deviceSerial, activationCode);
}

function changeDevice(deviceSerial, activationCode) {
    const data = new URLSearchParams();
    data.append('device_serial', deviceSerial);
    data.append('activation_code', activationCode);

    fetch('接口地址', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded'
        },
        body: data
    })
    .then(response => response.json())
    .then(result => {
        if (result.success) {
            ipcRenderer.send('show-alert', '换绑成功！');
        } else {
            ipcRenderer.send('show-alert', '换绑失败：' + (result.error || '未知错误'));
        }
    })
    .catch(error => {
        console.error('Error:', error);
        ipcRenderer.send('show-alert', '网络错误或服务器无响应');
    });
}
